@@ -107,6 +107,8 @@ class AdapterInterface(metaclass=abc.ABCMeta):
             and callable(subclass.get_resource_by_id)
             and hasattr(subclass, "get_all_parent_groups_for_group")
             and callable(subclass.get_all_parent_groups_for_group)
+            and hasattr(subclass, "get_facilities_by_attribute_with_attributes")
+            and callable(subclass.get_facilities_by_attribute_with_attributes)
             or NotImplemented
         )
 
@@ -401,3 +403,12 @@ class AdapterInterface(metaclass=abc.ABCMeta):
             return object_or_id.id
         else:
             return object_or_id
+
+    @staticmethod
+    def get_facilities_by_attribute_with_attributes(
+        self,
+        attr_name: str,
+        attr_value: Union[str, int, bool, List[str], dict[str, str]],
+        attr_names: List[str],
+    ) -> List[Facility]:
+        raise NotImplementedError
