@@ -2,7 +2,6 @@ import inspect
 from typing import List, Union, Optional
 
 from ldap3.core.exceptions import LDAPException
-from perun.connector.models.Resource import Resource
 
 from perun.connector.adapters.AdapterInterface import AdapterInterface
 from perun.connector.adapters.LdapAdapter import AdapterSkipException
@@ -14,6 +13,7 @@ from perun.connector.adapters.PerunRpcAdapter import (
 from perun.connector.models.Facility import Facility
 from perun.connector.models.Group import Group
 from perun.connector.models.Member import Member
+from perun.connector.models.Resource import Resource
 from perun.connector.models.User import User
 from perun.connector.models.UserExtSource import UserExtSource
 from perun.connector.models.VO import VO
@@ -360,3 +360,13 @@ class AdaptersManager(AdapterInterface):
         return self._execute_method_by_priority(
             self._get_caller_name(), group, map_unique_name
         )
+
+    def get_facilities_by_attribute_with_attributes(
+        self,
+        attr_name: str,
+        attr_value: Union[str, int, bool, List[str], dict[str, str]],
+        attr_names: List[str],
+    ) -> List[Facility]:
+        return self._execute_method_by_priority(
+            self._get_caller_name(), attr_name, attr_value, attr_names
+        )
