@@ -259,12 +259,12 @@ class LdapAdapter(AdapterInterface):
             ldap_result["cn"][0],
             ldap_result["description"][0],
             rp_identifier,
+            {},
         )
 
     def get_users_groups_on_facility(
         self, facility: Union[Facility, int], user: Union[User, int]
     ) -> List[Group]:
-
         if not facility:
             return []
 
@@ -633,6 +633,7 @@ class LdapAdapter(AdapterInterface):
                 facility["cn"][0],
                 facility["description"][0],
                 facility[rp_id_attr[0]] if rp_id_attr else "",
+                {},
             )
             for facility in facilities
         ]
@@ -663,6 +664,7 @@ class LdapAdapter(AdapterInterface):
             facility["cn"][0],
             facility["description"][0],
             facility[rp_id_attr[0]] if rp_id_attr else "",
+            {},
         )
 
     def get_resources_for_facility(
@@ -737,3 +739,11 @@ class LdapAdapter(AdapterInterface):
         self, group: Union[Group, int], map_unique_name=True
     ) -> List[Group]:
         raise AdapterSkipException
+
+    def get_facilities_by_attribute_with_attributes(
+        self,
+        attr_name: str,
+        attr_value: Union[str, int, bool, List[str], dict[str, str]],
+        attr_names: List[str],
+    ) -> List[Facility]:
+        raise AdapterSkipException
