@@ -1,6 +1,8 @@
 from typing import List, Union, Optional
 
-from perun.connector.models.Resource import Resource
+from perun.connector.perun_openapi.model.input_get_facilities import InputGetFacilities
+
+from perun.connector.perun_openapi.api.searcher_api import SearcherApi
 
 from perun.connector import perun_openapi
 from perun.connector.adapters.AdapterInterface import AdapterInterface
@@ -8,6 +10,7 @@ from perun.connector.models.Facility import Facility
 from perun.connector.models.Group import Group
 from perun.connector.models.Member import Member
 from perun.connector.models.MemberStatusEnum import MemberStatusEnum
+from perun.connector.models.Resource import Resource
 from perun.connector.models.User import User
 from perun.connector.models.UserExtSource import UserExtSource
 from perun.connector.models.VO import VO
@@ -23,12 +26,10 @@ from perun.connector.perun_openapi.api.groups_manager_api import GroupsManagerAp
 from perun.connector.perun_openapi.api.members_manager_api import MembersManagerApi
 from perun.connector.perun_openapi.api.registrar_manager_api import RegistrarManagerApi
 from perun.connector.perun_openapi.api.resources_manager_api import ResourcesManagerApi
-from perun.connector.perun_openapi.api.searcher_api import SearcherApi
 from perun.connector.perun_openapi.api.users_manager_api import UsersManagerApi
 from perun.connector.perun_openapi.api.vos_manager_api import VosManagerApi
 from perun.connector.perun_openapi.exceptions import ApiException
 from perun.connector.perun_openapi.model.attribute import Attribute
-from perun.connector.perun_openapi.model.input_get_facilities import InputGetFacilities
 from perun.connector.perun_openapi.model.input_set_facility_attributes import (
     InputSetFacilityAttributes,
 )
@@ -264,6 +265,7 @@ class PerunRpcAdapter(AdapterInterface):
                 facilities[0]["name"],
                 facilities[0]["description"],
                 rp_identifier,
+                {},
             )
 
     def get_users_groups_on_facility(
@@ -300,7 +302,6 @@ class PerunRpcAdapter(AdapterInterface):
             self._RP_ID_ATTR
         )
 
-    # TODO test this method once SearcherAPI is supported on Devel
     def get_facilities_by_attribute_value(
         self, attribute: dict[str, str]
     ) -> List[Facility]:
@@ -326,6 +327,7 @@ class PerunRpcAdapter(AdapterInterface):
                     perun_facility["name"],
                     perun_facility["description"],
                     "",
+                    {},
                 )
                 facility.rp_id = self._get_rp_id(facility)
                 facilities.append(facility)
@@ -432,7 +434,6 @@ class PerunRpcAdapter(AdapterInterface):
     def get_member_status_by_user_and_vo(
         self, user: Union[User, int], vo: Union[VO, int]
     ) -> Optional[str]:
-
         member = self.get_member_by_user(user, vo)
 
         if member is not None:
@@ -598,12 +599,10 @@ class PerunRpcAdapter(AdapterInterface):
     def _get_attributes(
         self,
         perun_attrs: List[dict[str, Union[str, int, bool, list[str], dict[str, str]]]],
-    ) -> dict[str, dict[str, Union[str, int, bool, list[str], dict[str, str]]]]:
+    ) -> dict[str, Union[str, int, bool, list[str], dict[str, str]]]:
         attributes = {}
         for perun_attr in perun_attrs:
-            perun_attr_name = (
-                perun_attr["namespace"] + ":" + perun_attr["friendly_name"]
-            )
+            perun_attr_name = perun_attr["namespace"] + ":" + perun_attr["friendlyName"]
 
             # for some reason open_api map int attributes as float
             if perun_attr["type"] == AttributeUtils.PERUN_INT:
@@ -780,6 +779,7 @@ class PerunRpcAdapter(AdapterInterface):
                     facility.name,
                     facility.description,
                     self._get_rp_id(facility.id) if fill_facility_rp_id else "",
+                    {},
                 )
                 for facility in facilities
             ]
@@ -840,6 +840,7 @@ class PerunRpcAdapter(AdapterInterface):
                     facility.name,
                     facility.description,
                     "" if not fill_rp_ids else self._get_rp_id(facility.id),
+                    {},
                 )
                 for facility in facilities
             ]
@@ -880,6 +881,7 @@ class PerunRpcAdapter(AdapterInterface):
                 facility.name,
                 facility.description,
                 self._get_rp_id(facility_id),
+                {},
             )
 
     def get_resources_for_facility(
@@ -934,7 +936,7 @@ class PerunRpcAdapter(AdapterInterface):
             facility = (
                 self.get_facility_by_id(resource.facility_id)
                 if map_facility
-                else Facility(resource.facility_id, "", "", "")
+                else Facility(resource.facility_id, "", "", "", {})
             )
             vo = (
                 self.get_vo(vo_id=resource.vo_id)
@@ -972,6 +974,37 @@ class PerunRpcAdapter(AdapterInterface):
             )
             return result
 
+    def get_facilities_by_attribute_with_attributes(
+        self,
+        attr_name: str,
+        attr_value: Union[str, int, bool, List[str], dict[str, str]],
+        attr_names: List[str],
+    ) -> List[Facility]:
+        with ApiClient(self._CONFIG) as api_client:
+            if self._RP_ID_ATTR not in attr_name:
+                attr_names.append(self._RP_ID_ATTR)
+
+            perun_facilities_attributes = FacilitiesManagerApi(
+                api_client
+            ).get_facilities_by_attribute_with_attributes(
+                attr_name, attr_value, attr_names
+            )
+
+            facilities = []
+            for facility_attrs in perun_facilities_attributes:
+                perun_facility = facility_attrs["facility"]
+                attrs = self._get_attributes(facility_attrs["attributes"])
+                facilities.append(
+                    Facility(
+                        perun_facility.id,
+                        perun_facility.name,
+                        perun_facility.description,
+                        attrs[self._RP_ID_ATTR],
+                        attrs,
+                    )
+                )
+            return facilities
+
     @staticmethod
     def __find_vo_in_list_by_id(vo_list, vo_id):
         for vo in vo_list:
