@@ -9,3 +9,6 @@ class HasIdAbstract(metaclass=abc.ABCMeta):
         if isinstance(other, HasIdAbstract):
             return self.id == other.id
         return False
+
+    def __hash__(self):
+        return hash((self.id))
