@@ -33,3 +33,6 @@ class Member(HasIdAbstract):
                 and self.status == other.status
             )
         return False
+
+    def __hash__(self):
+        return hash((self.id, self.vo, self.status))
