@@ -13,3 +13,6 @@ class User(HasIdAbstract):
         if isinstance(other, User):
             return self.id == other.id and self.name == other.name
         return False
+
+    def __hash__(self):
+        return hash((self.id, self.name))
