@@ -18,3 +18,6 @@ class VO(HasIdAbstract):
                 and self.short_name == other.short_name
             )
         return False
+
+    def __hash__(self):
+        return hash((self.id, self.name, self.short_name))
