@@ -4,7 +4,7 @@
 # if you have many models here with many references from one model to another this may
 # raise a RecursionError
 # to avoid this, import only the models that you directly need like:
-# from from perun.connector.perun_openapi.model.pet import Pet
+# from perun.connector.perun_openapi.model.pet import Pet
 # or import this package, but before doing it, use:
 # import sys
 # sys.setrecursionlimit(n)
@@ -17,9 +17,6 @@ from perun.connector.perun_openapi.model.app_state import AppState
 from perun.connector.perun_openapi.model.app_type import AppType
 from perun.connector.perun_openapi.model.application import Application
 from perun.connector.perun_openapi.model.application_form import ApplicationForm
-from perun.connector.perun_openapi.model.application_form_group import (
-    ApplicationFormGroup,
-)
 from perun.connector.perun_openapi.model.application_form_item import (
     ApplicationFormItem,
 )
@@ -44,6 +41,7 @@ from perun.connector.perun_openapi.model.attribute_policy_collection import (
     AttributePolicyCollection,
 )
 from perun.connector.perun_openapi.model.attribute_rights import AttributeRights
+from perun.connector.perun_openapi.model.attribute_rules import AttributeRules
 from perun.connector.perun_openapi.model.audit_event import AuditEvent
 from perun.connector.perun_openapi.model.audit_message import AuditMessage
 from perun.connector.perun_openapi.model.audit_messages_page_query import (
@@ -68,9 +66,18 @@ from perun.connector.perun_openapi.model.destination_propagation_type import (
     DestinationPropagationType,
 )
 from perun.connector.perun_openapi.model.destination_type import DestinationType
+from perun.connector.perun_openapi.model.enriched_ban_on_facility import (
+    EnrichedBanOnFacility,
+)
+from perun.connector.perun_openapi.model.enriched_ban_on_resource import (
+    EnrichedBanOnResource,
+)
+from perun.connector.perun_openapi.model.enriched_ban_on_vo import EnrichedBanOnVo
+from perun.connector.perun_openapi.model.enriched_ext_source import EnrichedExtSource
 from perun.connector.perun_openapi.model.enriched_facility import EnrichedFacility
 from perun.connector.perun_openapi.model.enriched_group import EnrichedGroup
 from perun.connector.perun_openapi.model.enriched_host import EnrichedHost
+from perun.connector.perun_openapi.model.enriched_identity import EnrichedIdentity
 from perun.connector.perun_openapi.model.enriched_resource import EnrichedResource
 from perun.connector.perun_openapi.model.enriched_vo import EnrichedVo
 from perun.connector.perun_openapi.model.entityless_attributes_by_keys import (
@@ -83,6 +90,9 @@ from perun.connector.perun_openapi.model.facility_propagation_state import (
     FacilityPropagationState,
 )
 from perun.connector.perun_openapi.model.facility_state import FacilityState
+from perun.connector.perun_openapi.model.facility_with_attributes import (
+    FacilityWithAttributes,
+)
 from perun.connector.perun_openapi.model.gen_data_node import GenDataNode
 from perun.connector.perun_openapi.model.gen_member_data_node import GenMemberDataNode
 from perun.connector.perun_openapi.model.graph_dto import GraphDTO
@@ -112,9 +122,15 @@ from perun.connector.perun_openapi.model.input_add_destination_to_multiple_servi
 from perun.connector.perun_openapi.model.input_add_destinations_defined_by_hosts_on_facility import (
     InputAddDestinationsDefinedByHostsOnFacility,
 )
+from perun.connector.perun_openapi.model.input_add_member_candidates import (
+    InputAddMemberCandidates,
+)
 from perun.connector.perun_openapi.model.input_assign_resource_tag_to_resource import (
     InputAssignResourceTagToResource,
 )
+from perun.connector.perun_openapi.model.input_assign_resource_tags_to_resource import (
+    InputAssignResourceTagsToResource,
+)
 from perun.connector.perun_openapi.model.input_attribute_definition import (
     InputAttributeDefinition,
 )
@@ -124,6 +140,9 @@ from perun.connector.perun_openapi.model.input_attribute_policy_collections impo
 from perun.connector.perun_openapi.model.input_attribute_rights import (
     InputAttributeRights,
 )
+from perun.connector.perun_openapi.model.input_block_services_on_destinations import (
+    InputBlockServicesOnDestinations,
+)
 from perun.connector.perun_openapi.model.input_change_non_authz_password_by_token import (
     InputChangeNonAuthzPasswordByToken,
 )
@@ -136,6 +155,7 @@ from perun.connector.perun_openapi.model.input_change_password_for_user import (
 from perun.connector.perun_openapi.model.input_check_password_strength import (
     InputCheckPasswordStrength,
 )
+from perun.connector.perun_openapi.model.input_consolidate import InputConsolidate
 from perun.connector.perun_openapi.model.input_copy_resource import InputCopyResource
 from perun.connector.perun_openapi.model.input_create_alternative_password import (
     InputCreateAlternativePassword,
@@ -230,12 +250,24 @@ from perun.connector.perun_openapi.model.input_get_paginated_users import (
 )
 from perun.connector.perun_openapi.model.input_get_resources import InputGetResources
 from perun.connector.perun_openapi.model.input_get_users import InputGetUsers
+from perun.connector.perun_openapi.model.input_invitations_from_csv import (
+    InputInvitationsFromCsv,
+)
+from perun.connector.perun_openapi.model.input_invite_member_candidates import (
+    InputInviteMemberCandidates,
+)
 from perun.connector.perun_openapi.model.input_lock_publications import (
     InputLockPublications,
 )
 from perun.connector.perun_openapi.model.input_remove_resource_tag_from_resource import (
     InputRemoveResourceTagFromResource,
 )
+from perun.connector.perun_openapi.model.input_remove_resource_tags_from_resource import (
+    InputRemoveResourceTagsFromResource,
+)
+from perun.connector.perun_openapi.model.input_remove_rich_destinations import (
+    InputRemoveRichDestinations,
+)
 from perun.connector.perun_openapi.model.input_reserve_password_for_login import (
     InputReservePasswordForLogin,
 )
@@ -356,10 +388,14 @@ from perun.connector.perun_openapi.model.input_specific_member import (
 from perun.connector.perun_openapi.model.input_submit_application import (
     InputSubmitApplication,
 )
+from perun.connector.perun_openapi.model.input_unlock_services_on_destinations import (
+    InputUnlockServicesOnDestinations,
+)
 from perun.connector.perun_openapi.model.input_update_application_mail import (
     InputUpdateApplicationMail,
 )
 from perun.connector.perun_openapi.model.input_update_ban import InputUpdateBan
+from perun.connector.perun_openapi.model.input_update_ban1 import InputUpdateBan1
 from perun.connector.perun_openapi.model.input_update_ban_for_facility import (
     InputUpdateBanForFacility,
 )
@@ -454,12 +490,20 @@ from perun.connector.perun_openapi.model.service_attributes import ServiceAttrib
 from perun.connector.perun_openapi.model.service_for_gui import ServiceForGUI
 from perun.connector.perun_openapi.model.service_state import ServiceState
 from perun.connector.perun_openapi.model.services_package import ServicesPackage
+from perun.connector.perun_openapi.model.set_role_for_group import SetRoleForGroup
+from perun.connector.perun_openapi.model.set_role_for_user import SetRoleForUser
 from perun.connector.perun_openapi.model.set_role_with_group_complementary_object import (
     SetRoleWithGroupComplementaryObject,
 )
+from perun.connector.perun_openapi.model.set_role_with_group_complementary_objects import (
+    SetRoleWithGroupComplementaryObjects,
+)
 from perun.connector.perun_openapi.model.set_role_with_user_complementary_object import (
     SetRoleWithUserComplementaryObject,
 )
+from perun.connector.perun_openapi.model.set_role_with_user_complementary_objects import (
+    SetRoleWithUserComplementaryObjects,
+)
 from perun.connector.perun_openapi.model.simple_attribute import SimpleAttribute
 from perun.connector.perun_openapi.model.sorting_order import SortingOrder
 from perun.connector.perun_openapi.model.sponsor import Sponsor
@@ -479,12 +523,20 @@ from perun.connector.perun_openapi.model.task_status import TaskStatus
 from perun.connector.perun_openapi.model.thanks import Thanks
 from perun.connector.perun_openapi.model.thanks_for_gui import ThanksForGUI
 from perun.connector.perun_openapi.model.type import Type
+from perun.connector.perun_openapi.model.unset_role_for_group import UnsetRoleForGroup
+from perun.connector.perun_openapi.model.unset_role_for_user import UnsetRoleForUser
 from perun.connector.perun_openapi.model.unset_role_with_group_complementary_object import (
     UnsetRoleWithGroupComplementaryObject,
 )
+from perun.connector.perun_openapi.model.unset_role_with_group_complementary_objects import (
+    UnsetRoleWithGroupComplementaryObjects,
+)
 from perun.connector.perun_openapi.model.unset_role_with_user_complementary_object import (
     UnsetRoleWithUserComplementaryObject,
 )
+from perun.connector.perun_openapi.model.unset_role_with_user_complementary_objects import (
+    UnsetRoleWithUserComplementaryObjects,
+)
 from perun.connector.perun_openapi.model.user import User
 from perun.connector.perun_openapi.model.user_ext_source import UserExtSource
 from perun.connector.perun_openapi.model.users_order_column import UsersOrderColumn
